@@ -90,7 +90,7 @@ __copyright__ = 'Copyright 2014-2019 - Block Research Group, ETH Zurich'
 __license__ = 'MIT License'
 __email__ = 'vanmelet@ethz.ch'
 
-__version__ = '1.7.0'
+__version__ = '1.8.1'
 
 version = LooseVersion(compas.__version__)
 versionstring = version.vstring.split('-')[0]
@@ -177,7 +177,7 @@ __all__ = [
     'is_windows', 'is_linux', 'is_osx', 'is_mono', 'is_ironpython', 'is_rhino', 'is_blender',
     'set_precision',
     'get',
-    'json_dump', 'json_load', 'json_dumps', 'json_loads'
+    'json_dump', 'json_load', 'json_dumps', 'json_loads',
 ]
 
 
